summaryrefslogtreecommitdiff
path: root/blessings/tests/test_sequences.py
diff options
context:
space:
mode:
Diffstat (limited to 'blessings/tests/test_sequences.py')
-rw-r--r--blessings/tests/test_sequences.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/blessings/tests/test_sequences.py b/blessings/tests/test_sequences.py
index f42a52c..c0cafce 100644
--- a/blessings/tests/test_sequences.py
+++ b/blessings/tests/test_sequences.py
@@ -192,8 +192,8 @@ def test_horizontal_location(all_terms):
assert (t.stream.getvalue() == expected_output), (
repr(t.stream.getvalue()), repr(expected_output))
- # skip 'screen', hpa is proxied (see later tests)
- if all_terms != 'screen':
+ # skip 'screen', 'ansi': hpa is proxied (see later tests)
+ if all_terms not in ('screen', 'ansi'):
child(all_terms)
@@ -211,7 +211,7 @@ def test_vertical_location(all_terms):
assert (t.stream.getvalue() == expected_output)
# skip 'screen', vpa is proxied (see later tests)
- if all_terms != 'screen':
+ if all_terms not in ('screen', 'ansi'):
child(all_terms)